@@ -1,5 +1,5 @@
 //!error system
-use std::{fmt, io, num, str};
+use std::{error, fmt, io, num, str};
 
 #[derive(Debug, PartialEq)]
 pub enum ParseErr {
@@ -10,6 +10,22 @@ pub enum ParseErr {
     UriErr,
     Invalid,
     Empty,
+    #[cfg(feature = "rust-tls")]
+    Rustls(rustls::Error),
+}
+
+impl error::Error for ParseErr {
+    fn source(&self) -> Option<&(dyn error::Error + 'static)> {
+        use self::ParseErr::*;
+
+        match self {
+            Utf8(e) => Some(e),
+            Int(e) => Some(e),
+            StatusErr | HeadersErr | UriErr | Invalid | Empty => None,
+            #[cfg(feature = "rust-tls")]
+            Rustls(e) => Some(e),
+        }
+    }
 }
 
 impl fmt::Display for ParseErr {
@@ -24,11 +40,20 @@ impl fmt::Display for ParseErr {
             StatusErr => "status line contains invalid values",
             HeadersErr => "headers contain invalid values",
             UriErr => "uri contains invalid characters",
+            #[cfg(feature = "rust-tls")]
+            Rustls(_) => "rustls error",
         };
         write!(f, "ParseErr: {}", err)
     }
 }
 
+#[cfg(feature = "rust-tls")]
+impl From<rustls::Error> for ParseErr {
+    fn from(e: rustls::Error) -> Self {
+        ParseErr::Rustls(e)
+    }
+}
+
 impl From<num::ParseIntError> for ParseErr {
     fn from(e: num::ParseIntError) -> Self {
         ParseErr::Int(e)
@@ -48,6 +73,18 @@ pub enum Error {
     Tls,
 }
 
+impl error::Error for Error {
+    fn source(&self) -> Option<&(dyn error::Error + 'static)> {
+        use self::Error::*;
+
+        match self {
+            IO(e) => Some(e),
+            Parse(e) => Some(e),
+            Tls => None,
+        }
+    }
+}
+
 impl fmt::Display for Error {
     fn fmt(&self, f: &mut fmt::Formatter) -> fmt::Result {
         use self::Error::*;
